@@ -33,13 +33,17 @@ def get_ip():
     return subprocess.check_output(["hostname", "-I"]).split()[0].decode()
 
 
-def update_system(package):
+def update_system(*packages):
     print(
         subprocess.run(
-            ["/home/gaea/runinenv", "/home/gaea/app", "pip", "install", "-U", package],
+            ["/home/gaea/runinenv", "/home/gaea/app", "pip", "install", "-U"]
+            + list(packages),
             capture_output=True,
         )
     )
+    print(
+        subprocess.run(["sudo", "supervisorctl", "restart", "all"], capture_output=True)
+    )
 
 
 def get_versions(package):
@@ -161,7 +165,12 @@ class Software:
 
     def post(self):
         """"""
-        web.enqueue(update_system, "canopy-platform")  # TODO FIXME
+        web.enqueue(
+            update_system,
+            "canopy-platform",
+            "webint",
+            *[a.project_name for a in web.get_apps().keys()],
+        )
         return "software update has been started"
 
 
